#
# spec file for package python-zope.configuration
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2013 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-zope.configuration%{psuffix}
Version:        6.0
Release:        1.1
Summary:        Zope Configuration Markup Language (ZCML)
License:        ZPL-2.1
URL:            http://www.python.org/pypi/zope.configuration
Source:         https://files.pythonhosted.org/packages/source/z/zope.configuration/zope_configuration-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-setuptools
Requires:       python-zope.i18nmessageid
Requires:       python-zope.interface
Requires:       python-zope.schema >= 4.9
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module manuel}
BuildRequires:  %{python_module zope.i18nmessageid}
BuildRequires:  %{python_module zope.interface}
BuildRequires:  %{python_module zope.schema >= 4.9}
BuildRequires:  %{python_module zope.testing}
BuildRequires:  %{python_module zope.testrunner}
%endif
%python_subpackages

%description
The zope configuration system provides an extensible system for supporting
various kinds of configurations.

It is based on the idea of configuration directives. Users of the configuration
system provide configuration directives in some language that express
configuration choices. The intent is that the language be pluggable. An XML
language is provided by default.

%prep
%setup -q -n zope_configuration-%{version}
rm -rf zope.configuration.egg-info

%build
%pyproject_wheel

%install
%if !%{with test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
%python_expand PYTHONPATH=src %{_bindir}/zope-testrunner-%{$python_bin_suffix} -vvv --test-path src
%endif

%if !%{with test}
%files %{python_files}
%license LICENSE.txt
%doc CHANGES.rst COPYRIGHT.txt README.rst
%dir %{python_sitelib}/zope
%{python_sitelib}/zope/configuration
%{python_sitelib}/zope.configuration-%{version}.dist-info
%{python_sitelib}/zope.configuration-6.0-*-nspkg.pth
%endif

%changelog
* Tue Dec 17 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 6.0:
  * Add support for checking environment variables in zcml conditions. Use
    envvar or not-envvar. not-envvar is true when the variable is not set,
    is empty, or has one of the usual 'false' values like '0'.
  * Add support for Python 3.12, 3.13.
  * Drop support for Python 3.7.
- Switch to pyproject macros.
- No more greedy globs in %%files.
* Sat Mar 16 2024 Dirk Müller <dmueller@suse.com>
- update to 5.0.1:
  * Fix tests when running from a distribution.
* Fri Dec 29 2023 Dirk Müller <dmueller@suse.com>
- update to 5.0:
  * Drop support for Python 2.7, 3.5, 3.6.
  * Add support for Python 3.11.
* Thu Jun  1 2023 Dirk Müller <dmueller@suse.com>
- use python3 module python for sle15
* Fri Sep 16 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- version update to 4.4.1
  * Avoid creating reference cycles through tracebacks in reraise (change imported from six).
  * Add support for Python 3.9, 3.10.
* Tue Mar 24 2020 pgajdos@suse.com
- version update to 4.4.0
  - Ensure a consistent interface resolution order for all objects. See
    `issue 49 <https://github.com/zopefoundation/zope.configuration/issues/49>`_.
  - Drop support for Python 3.4.
  - Add support for Python 3.8.
- deleted sources
  - pre_checkin.sh (not needed)
* Thu Apr  4 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 4.3.1
  4.2.0
  * Reach 100%% automated test coverage.
  * Add support for Python 3.7.
  * Drop support for Python 3.3.
  * Drop support for python setup.py test.
  * Fix the doctests with zope.schema 4.7 and above.
  * More classes and exceptions enhancements.
  4.2.1
  * Fix GlobalObject no longer allowing just a single ‘.’.
  4.2.2
  * Fix GlobalObject no longer allowing multiple leading dots.
  * Add __all__ to all modules listing the documented members of
    the module.
  4.3.0
  * Simplify exception chaining and nested exception error messages.
  4.3.1
  * Do not break when running the tests from a wheel.
- drop *-doc subpackage, use multibuild instead
* Sun Jul 16 2017 aloisio@gmx.com
- Update to version 4.1.0
  * Drop support for Python 2.6 and 3.2.
  * Add support for Python 3.5 and 3.6.
  * Fix the domain of MessageID fields to be a native string.
    Previously on Python 3 they were bytes, which meant that they
    couldn’t be used to find translation utilities registered by
    zope.i18n. See issue 17.
- Split docs and tests into separate -doc package since running
  tests and sometimes building docs had become very messy.
  Also see (gh#/zopefoundation/zope.proxy#18)
- Converted to single-spec
* Fri May 15 2015 benoit.monin@gmx.fr
- update to version 4.0.3:
  * Added explicit support for Python 3.4.
- point the source URL to pypi
- add fdupes as BuildRequires and call it after install
- pass -q to the test to avoid spamming the build log
- rename CHANGES.txt to CHANGES.rst: changed upstream
- rename README.txt to README.rst: changed upstream
* Mon Jul 29 2013 hpj@urpla.net
- version 4.0.2: initial build
